==> igniteui-react-core-18.0.0.tgz: package/esm5/lib/WebTabComponentEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabDescriptionMetadata } from "./WebTabDescriptionMetadata";
import { WebTabComponentEventArgsDescription } from "./WebTabComponentEventArgsDescription";
/**
 * @hidden
 */
var WebTabComponentEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTabComponentEventArgsDescriptionMetadata, _super);
    function WebTabComponentEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTabComponentEventArgsDescriptionMetadata.b = function (a) {
        if (WebTabComponentEventArgsDescriptionMetadata.a == null) {
            WebTabComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTabComponentEventArgsDescriptionMetadata.c(WebTabComponentEventArgsDescriptionMetadata.a);
        }
        if (a.g(WebTabComponentEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(WebTabComponentEventArgsDescriptionMetadata.a);
        WebTabDescriptionMetadata.d(a);
    };
    WebTabComponentEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:TabComponentEventArgs");
        a.item("Detail", "ExportedType:WebTab");
    };
    WebTabComponentEventArgsDescriptionMetadata.d = function (a) {
        WebTabComponentEventArgsDescriptionMetadata.b(a);
        a.u("WebTabComponentEventArgs", function () { return new WebTabComponentEventArgsDescription(); });
        a.t("WebTabComponentEventArgs", WebTabComponentEventArgsDescriptionMetadata.a);
    };
    WebTabComponentEventArgsDescriptionMetadata.$t = markType(WebTabComponentEventArgsDescriptionMetadata, 'WebTabComponentEventArgsDescriptionMetadata');
    WebTabComponentEventArgsDescriptionMetadata.a = null;
    return WebTabComponentEventArgsDescriptionMetadata;
}(Base));
export { WebTabComponentEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebTabComponentEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabDescriptionMetadata } from "./WebTabDescriptionMetadata";
import { WebTabComponentEventArgsDescription } from "./WebTabComponentEventArgsDescription";
/**
 * @hidden
 */
var WebTabComponentEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTabComponentEventArgsDescriptionMetadata, _super);
    function WebTabComponentEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTabComponentEventArgsDescriptionMetadata.b = function (a) {
        if (WebTabComponentEventArgsDescriptionMetadata.a == null) {
            WebTabComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTabComponentEventArgsDescriptionMetadata.c(WebTabComponentEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebTabComponentEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebTabComponentEventArgsDescriptionMetadata.a);
        WebTabDescriptionMetadata.d(a);
    };
    WebTabComponentEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:TabComponentEventArgs");
        a.item("Detail", "ExportedType:WebTab");
    };
    WebTabComponentEventArgsDescriptionMetadata.d = function (a) {
        WebTabComponentEventArgsDescriptionMetadata.b(a);
        a.aa("WebTabComponentEventArgs", function () { return new WebTabComponentEventArgsDescription(); });
        a.z("WebTabComponentEventArgs", WebTabComponentEventArgsDescriptionMetadata.a);
    };
    WebTabComponentEventArgsDescriptionMetadata.$t = markType(WebTabComponentEventArgsDescriptionMetadata, 'WebTabComponentEventArgsDescriptionMetadata');
    WebTabComponentEventArgsDescriptionMetadata.a = null;
    return WebTabComponentEventArgsDescriptionMetadata;
}(Base));
export { WebTabComponentEventArgsDescriptionMetadata };
